Documentation for pyscal
========================

.. image:: images/pyscal-logo.png
   :width: 200

Relative permeability/SCAL support in reservoir simulation.

.. toctree::
   :maxdepth: 2

   introduction
   installation
   usage
   modelling
   history
   contributing

.. toctree::
   :hidden:
   :maxdepth: 10
   :caption: Python API

   pyscal/pyscal

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
